version 9
clear
drop _all
set mem 256m

use "C:\BellemareLandEconomicsLandRights.dta"

drop yhat

replace titled = 0 if titled==.
gen owned_titled = 1 if owned==1 & titled==1
replace owned_titled = 0 if owned==0 | titled==0
replace owned_titled=0 if titled==.

replace sell=0 if sell==.
replace tomb=0 if tomb==.
replace lease_out=0 if lease_out==. 
replace trees=0 if trees==. 
replace kids=0 if kids==.

gen trans_rights = 1 if kids==1 | sell==1 | lease_out==1
replace trans_rights = 0 if kids==0 & sell==0 & lease_out==0

gen use_rights = 1 if tomb==1 | trees==1
replace use_rights = 0 if tomb==0 & trees==0

gen count = sell + tomb + lease_out + trees + kids

gen years_owned = 2002 - (1900+year_owned) if year_owned > 3
replace years_owned = 2002 - (2000+year_owned) if year_owned<3

gen purchased = 1 if mode_owned==1
replace purchased = 0 if mode_owned~=1

gen inherited = 1 if mode_owned==2
replace inherited = 0 if mode_owned~=2

gen gift = 1 if mode_owned==3
replace gift = 0 if mode_owned~=3

gen exploit = 1 if mode_owned==4
replace exploit = 0 if mode_owned~=4

replace ln_urea = ln((urea+0.001)/area)
replace ln_manure = ln((manure+0.001)/area)
replace ln_npk = ln((npk+0.001)/area)

gen some_full = 1 if count>0
replace some_full = 0 if count==0

replace plan_title = 0 if plan_title==.

replace ln_area = ln(area+0.001)
replace ln_manure = ln((manure+0.001)/area)
replace ln_labor = ln(([adult+child+hired+help]+0.001)/area)
replace ln_traction = ln((traction+0.001)/area)


label variable ln_yield "Yield"
label variable ln_area "Cultivated Area"
label variable ln_adult "Adult Labor"
label variable ln_child "Child Labor" 
label variable ln_help "Help Labor"
label variable ln_hired " Hired Labor" 
label variable ln_traction "Animal Traction" 
label variable ln_urea "Urea"
label variable ln_manure "Manure"
label variable ln_npk "NPK"
label variable ln_c "Carbon" 
label variable ln_n "Nitrogen" 
label variable ln_ph "Soil pH" 
label variable ln_pot "Potassium" 
label variable ln_clay "Clay" 
label variable ln_silt "Silt" 
label variable ln_sand "Sand" 
label variable disease "Crop Disease" 
label variable color_bl "Black Soil"
label variable color_rd "Red Soil" 
label variable color_brwh "Brown or White Soil"
label variable texture_cl "Clay Soil"
label variable texture_sd "Sand Soil" 
label variable texture_li "Loam Soil" 
label variable loc_lowland "Lowland Plot"
label variable loc_summit "Hilltop Plot" 
label variable loc_side "Hillside Plot" 
label variable rain "Irrigated by Rain"
label variable dam "Irrigated by Dam" 
label variable spring "Irrigated by Spring" 
label variable sell "Right to Sell" 
label variable tomb "Right to Build a Tomb" 
label variable lease_out "Right to Lease Out" 
label variable trees "Right to Plant Trees" 
label variable kids "Children Will Have Same Rights" 
label variable inherited "Inherited Plot"
label variable purchased "Purchased Plot" 
label variable gift "Plot Received as Gift" 
label variable exploit "Plot Obtained through Clearing" 
label variable owned_titled "Titled Plot"
label variable plan_title "Intent to Title the Plot"
label variable wtp_title "WTP Per Are to Title the Plot"
label variable trans_rights "Transfer Rights"
label variable use_rights "Use Rights"
label variable count "Count of Informal Rights"


replace ln_yield = ln(yield+0.001)


log using "C:\BellemareLandEconomics", replace



mean yield if owned_titled==1
mean yield if owned_titled==0

label variable yield "Yield (Kg/Are)"

kdensity yield if owned_titled==0 & owned==1, w(15) epanechnikov addplot(kdensity yield if owned_titled==1 & owned==1, w(15) epanechnikov) title(Distribution of Rice Yields) legend(label(1 "Untitled Plots") lpattern(dash)) legend(label(2 "Titled Plots")) lpattern(dash)
more

replace wtp_title = 0 if wtp_title==.
replace wtp_title = wtp_title/area



* Table 1 *

sum yield area manure labor traction chat nhat pothat phhat clayhat silthat sandhat hhsize depr female single total_area disease dist_house color_bl color_rd color_brwh loc_lowland loc_summit loc_side rain dam spring lease_out sell kids trees tomb owned_titled inherited purchased gift exploit wtp_title plan_title if owned==1 & yield>0

sum wtp_title plan_title if owned_titled==0 & owned==1 & yield>0


replace wtp_title = wtp_title*area
replace wtp_title = ln(wtp_title + (wtp_title^2 +1)^0.5)



* Table 2 *

sum sell kids tomb lease_out trees inherited purchased gift exploit use_rights trans_rights count some_full inherited purchased gift exploit if owned_titled==0 & owned==1 & yield>0
sum sell kids tomb lease_out trees use_rights trans_rights count some_full inherited purchased gift exploit if owned_titled==1 & owned==1 & yield>0

ttest sell if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest kids if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest tomb if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest lease_out if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest trees if owned==1 & owned==1 & yield>0, by(owned_titled) unequal

ttest use_rights if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest trans_rights if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest count if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest some_full if owned==1 & owned==1 & yield>0, by(owned_titled) unequal

ttest inherited if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest purchased if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest gift if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest exploit if owned==1 & owned==1 & yield>0, by(owned_titled) unequal



sum chat nhat phhat pothat clayhat silthat sandhat ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned_titled==0 & owned==1 & yield>0
sum chat nhat phhat pothat clayhat silthat sandhat ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned_titled==1 & owned==1 & yield>0

ttest chat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest nhat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest phhat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest pothat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest clayhat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest silthat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest sandhat if owned==1 & owned==1 & yield>0, by(owned_titled) unequal

ttest ln_c if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_n if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_ph if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_pot if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_clay if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_silt if owned==1 & owned==1 & yield>0, by(owned_titled) unequal
ttest ln_sand if owned==1 & owned==1 & yield>0, by(owned_titled) unequal

gen instrument = 1 if inherited==1 | gift==1
replace instrument = 0 if inherited==0 & gift==0


* Table 3 (and also table 4d) *

set seed 123456789
reg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 


ivreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand (owned_titled = instrument) if owned==1 & yield>0, first cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 

set seed 123456789
xtreg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid) vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2

xtreg owned_titled instrument sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid)

xtivreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand (owned_titled = instrument) if owned==1 & yield>0, fe i(hhid)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2


* Table 4a *

reg ln_yield owned_titled ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, cluster(village)


ivreg ln_yield ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring (owned_titled = instrument) if owned==1 & yield>0, first cluster(village)


xtreg ln_yield owned_titled ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, fe i(hhid) cluster(village)
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2

xtreg owned_titled instrument ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, fe i(hhid)

xtivreg ln_yield ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring (owned_titled = instrument) if owned==1 & yield>0, fe i(hhid)
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2



* Table 4b *

set seed 123456789
reg ln_yield owned_titled ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
 
ivreg ln_yield ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand (owned_titled = instrument) if owned==1 & yield>0, first cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand


set seed 123456789
xtreg ln_yield owned_titled ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid) vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2

xtreg owned_titled instrument ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid)

xtivreg ln_yield ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand (owned_titled = instrument) if owned==1 & yield>0, fe i(hhid)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2



* Table 4c *

reg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, cluster(village)
test sell lease_out kids trees tomb 

ivreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring (owned_titled = instrument) if owned==1 & yield>0, first cluster(village)
test sell lease_out kids trees tomb 

xtreg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, fe i(hhid) cluster(village)
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2

xtreg owned_titled instrument sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, fe i(hhid)
 

xtivreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring (owned_titled = instrument) if owned==1 & yield>0, fe i(hhid)
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2



* Table 5 *

reg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, vce(bootstrap, reps(500)) cluster(village)
test sell lease_out kids trees tomb 

xtreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring if owned==1 & yield>0, fe i(hhid) vce(bootstrap, reps(500)) cluster(village)
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2

set seed 123456789
reg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 

set seed 123456789
xtreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid) vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 
egen ybar = mean(ln_yield)
gen y2 = (ln_yield - ybar)^2
predict resid, e
gen e2 = resid^2
drop resid
egen sse = sum(e2)
egen sst = sum(y2)
gen r2 = 1 - sse/sst
sum r2
drop sse sst y2 e2 ybar r2


* "Preferred-Specification" Tests *


xtreg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid)
est store A

xtivreg ln_yield sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand (owned_titled = instrument) if owned==1 & yield>0, fe i(hhid)
est store B

hausman B A 

set seed 123456789
xtreg ln_yield owned_titled sell lease_out kids trees tomb ln_area disease dist_house color_rd color_brwh loc_summit loc_side dam spring ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand if owned==1 & yield>0, fe i(hhid) vce(bootstrap, reps(500)) cluster(village)
test ln_c ln_n ln_ph ln_pot ln_clay ln_silt ln_sand
test sell lease_out kids trees tomb 


log close




